@@ -1,16 +1,18 @@
 """Numpydoc-style docstring parsing.
 
-.. seealso:: https://numpydoc.readthedocs.io/en/latest/format.html
+:see: https://numpydoc.readthedocs.io/en/latest/format.html
 """
 
 import inspect
 import itertools
 import re
 import typing as T
+from textwrap import dedent
 
 from .common import (
     Docstring,
     DocstringDeprecated,
+    DocstringExample,
     DocstringMeta,
     DocstringParam,
     DocstringRaises,
@@ -67,7 +69,8 @@ class Section:
         This pattern will match this instance's ``title`` attribute in
         an anonymous group.
         """
-        return r"^({})\s*?\n{}\s*$".format(self.title, "-" * len(self.title))
+        dashes = "-" * len(self.title)
+        return rf"^({self.title})\s*?\n{dashes}\s*$"
 
     def parse(self, text: str) -> T.Iterable[DocstringMeta]:
         """Parse ``DocstringMeta`` objects from the body of this section.
@@ -112,7 +115,7 @@ class _SphinxSection(Section):
 
     @property
     def title_pattern(self) -> str:
-        return r"^\.\.\s*({})\s*::".format(self.title)
+        return rf"^\.\.\s*({self.title})\s*::"
 
 
 class ParamSection(_KVSection):
@@ -222,6 +225,44 @@ class DeprecationSection(_SphinxSection):
         )
 
 
+class ExamplesSection(Section):
+    """Parser for numpydoc examples sections.
+
+    E.g. any section that looks like this:
+        >>> import numpy.matlib
+        >>> np.matlib.empty((2, 2))    # filled with random data
+        matrix([[  6.76425276e-320,   9.79033856e-307], # random
+                [  7.39337286e-309,   3.22135945e-309]])
+        >>> np.matlib.empty((2, 2), dtype=int)
+        matrix([[ 6600475,        0], # random
+                [ 6586976, 22740995]])
+    """
+
+    def parse(self, text: str) -> T.Iterable[DocstringMeta]:
+        """Parse ``DocstringExample`` objects from the body of this section.
+
+        :param text: section body text. Should be cleaned with
+                     ``inspect.cleandoc`` before parsing.
+        """
+        lines = dedent(text).strip().splitlines()
+        while lines:
+            snippet_lines = []
+            description_lines = []
+            while lines:
+                if not lines[0].startswith(">>>"):
+                    break
+                snippet_lines.append(lines.pop(0))
+            while lines:
+                if lines[0].startswith(">>>"):
+                    break
+                description_lines.append(lines.pop(0))
+            yield DocstringExample(
+                [self.key],
+                snippet="\n".join(snippet_lines) if snippet_lines else None,
+                description="\n".join(description_lines),
+            )
+
+
 DEFAULT_SECTIONS = [
     ParamSection("Parameters", "param"),
     ParamSection("Params", "param"),
@@ -243,8 +284,8 @@ DEFAULT_SECTIONS = [
     ReturnsSection("Return", "returns"),
     YieldsSection("Yields", "yields"),
     YieldsSection("Yield", "yields"),
-    Section("Examples", "examples"),
-    Section("Example", "examples"),
+    ExamplesSection("Examples", "examples"),
+    ExamplesSection("Example", "examples"),
     Section("Warnings", "warnings"),
     Section("Warning", "warnings"),
     Section("See Also", "see_also"),
